#include <IGame.h>
#include <string.h>

#define		FLOOR		0
#define		WALL		1
#define		SNAKE		2
#define		FOOD		3
#define		BORDER		4

#define		MOVE_LEFT	137
#define		MOVE_RIGHT	371
#define		MOVE_UP		149
#define		MOVE_DOWN	263

#define		MAXLEVEL	35
#define		LEVELS_PER_EPISODE	9

static volatile int timer = 0;
static void timer_f() {
	++timer;
}
END_OF_STATIC_FUNCTION(timer_f);

GameSettings *settings = 0;

/*
GameSettings settings[] = {
	{ "start", "start episode", "first|second|third|fourth", 0 },
	//{ "colors", "colors", "default|BorgX", 0 },
	{ "colors", "colors", "", 0 },
	{ 0, 0, 0, 0 }
};
*/

int append_color_scheme(const char *filename, int, void *) {
	char buf[64];
	strcpy(buf, filename);
	char *name = get_filename(buf);
	char *ext = get_extension(name);
	ext[-1] = 0;
	strcat(settings[1].options, name);
	strcat(settings[1].options, "|");
	return 0;
}

class Centipede : public IGame {
	private:
		int highscore;
		bool finnished;

		int x, y, tileSize;

		int color[5][3];
		int col_edit_back,col_text,col_edit_text,col_border,col_back;
		int maxWait;

		int matrix[50][50];
		int startx, starty;
		int foodx, foody;
		int length;
		int direction, lastdir;
		int snake[1000][2];

		int growth;
		int drop;
		bool there_is_food;
		int steps;
		bool handledLastKey;
		int wait;

		bool isPlaying;
		bool gameOver;
		int score;
		int lives;
		int speed;
		int growthLevel;
		int level;
		int pieces;
		int maxPieces;

		bool paused;
		int key_buffer[8];

	private:
		void GetDxDy(int *dx, int *dy);
		bool CanMove();
		bool CanMoveNext();
		void DropFood();
		bool HaveFood();
		void Crashed();
		void RestartLevel(int level);
		void LoadArena(int level);
		void DrawScore(BITMAP *bmp);

		void MsgChar(int c);
		void MsgTimer();
		void Play();

		void MoveSnake();
		void Reset();
		void LoadColors(int index);

		void draw_3d_frame(BITMAP *bmp, int x1, int y1, int x2, int y2, int c1, int c2, int c3) {
			if (c1 >= 0) rectfill(bmp, x1, y1, x2, y2, c1);

			int c4 = makecol(getr(c2) + (getr(c3) - getr(c2))/3, getg(c2) + (getg(c3) - getg(c2))/3, getb(c2) + (getb(c3) - getb(c2))/3);
			int c5 = makecol(getr(c3) - (getr(c3) - getr(c2))/3, getg(c3) - (getg(c3) - getg(c2))/3, getb(c3) - (getb(c3) - getb(c2))/3);

			vline(bmp, x1, y1, y2, c4);
			hline(bmp, x1, y1, x2, c4);
			vline(bmp, x1+1, y1+1, y2-1, c2);
			hline(bmp, x1+1, y1+1, x2-1, c2);
			vline(bmp, x2-1, y1+1, y2, c5);
			hline(bmp, x1+1, y2-1, x2, c5);
			hline(bmp, x1, y2, x2, c3);
			vline(bmp, x2, y1, y2, c3);
		}

	public:
		Centipede() : IGame() {
			paused = false;

			settings = new GameSettings[3];

			settings[0].name = new char[64];		strcpy(settings[0].name, "start");
			settings[0].label = new char[64];		strcpy(settings[0].label, "start episode");
			settings[0].options = new char[64];		strcpy(settings[0].options, "first|second|third|fourth");
			settings[0].value = 0;

			settings[1].name = new char[64];		strcpy(settings[1].name, "colors");
			settings[1].label = new char[64];		strcpy(settings[1].label, "colors");
			settings[1].options = new char[4096];
			settings[1].options[0] = 0;
			settings[1].value = 0;

			settings[2].name = 0;
			settings[2].label = 0;
			settings[2].options = 0;
			settings[2].value = 0;
		}

		~Centipede() {
			int i=0;
			while (true) {
				if (settings[i].name == 0) {
					break;
				}
				else {
					delete [] settings[i].name;
					delete [] settings[i].label;
					delete [] settings[i].options;
				}

				++i;
			}

			delete [] settings;
			settings = 0;
		}

		void SetGamePath(const char *path) {
			IGame::SetGamePath(path);

			char mask[128];
			usprintf(mask, "%s*.col", game_path);
			for_each_file_ex(mask, 0, 0, append_color_scheme, 0);
			//for_each_file_ex("games/centipede/*.col", 0, 0, append_color_scheme, 0);
			settings[1].options[strlen(settings[1].options)-1] = 0;
		}

		char *GetName() {
			return "Centipede";
		}

		char *GetAuthor() {
			return "Miran Amon";
		}

		char *GetDescription() {
			return "A simple Worm/Nibbles/Centipede/Snake clone with many levels.";
		}

		char *GetVersion() {
			return "1.00";
		}

		char *GetIconPath() {
			return "icon.bmp";
		}

		bool Init() {
			if (!IGame::Init()) {
				return false;
			}

			score = 0;
			highscore = 0;
			finnished = false;

			Reset();
			maxWait = 3;
			level = settings[0].value * LEVELS_PER_EPISODE;
			RestartLevel(level);

			LoadColors(settings[1].value);

			tileSize = SCREEN_H/50;
			y = (SCREEN_H - tileSize*50)/2;
			if (tileSize*50 == SCREEN_H && SCREEN_H > 200) {
				tileSize = (SCREEN_H-10)/50;
				y = (SCREEN_H - tileSize*50)/2;
			}

			x = y;

			for (int i=0; i<8; i++) {
				key_buffer[i] = 0;
			}

			return true;
		}

		void Deinit() {
			// custom deinitialization goes here

			// no more Allegro calls after this line!
			IGame::Deinit();
		}

		void Draw(BITMAP *bmp) {
			// Do all the drawing here. Draw only to the canvas bitmap.
			clear_to_color(bmp, col_back);

			int r,g,b;
			r = (int)(getr(color[FLOOR][0])*0.75f);
			g = (int)(getg(color[FLOOR][0])*0.75f);
			b = (int)(getb(color[FLOOR][0])*0.75f);

			int iy, ix;
			int x = MAX(8, this->x);
			for (iy=0; iy<50; iy++)	{
				for (ix=0; ix<50; ix++) {
					draw_3d_frame(bmp, x+ix*tileSize, y+iy*tileSize, x+ix*tileSize+tileSize-1, y+iy*tileSize+tileSize-1, color[matrix[ix][iy]][0], color[matrix[ix][iy]][1], color[matrix[ix][iy]][2]);
				}
			}

			rect(bmp, x-1, y-1, x + 50*tileSize, y + 50*tileSize, color[BORDER][0]);

			DrawScore(bmp);
		}

		int Logic(int keys[8], int[4], float) {
			if (paused) {
				return 0;
			}

			if (isPlaying) {
				if (score > highscore) {
					highscore = score;
				}

				for (int i=0; i<8; i++) {
					if (keys[i]) {
						if (key_buffer[i] == 0) {
							MsgChar(i);
							key_buffer[i] = 1;
						}
					}
					else {
						key_buffer[i] = 0;
					}
				}

				while (timer) {
					--timer;
					MsgTimer();
				}
			}
			else {
				//if (keys[4] || keys[5] || keys[6] || keys[7]) {
				//if (keys[0] || keys[1] || keys[2] || keys[3] || keys[4]) {
				if (keys[4]) {
					timer = 0;
					clear_keybuf();
					Play();
				}
			}

			return gameOver ? 1 : 0;
		}

		int Score() {
			// Return -1 if this game doesn't have points, otherwise the last
			// valid score where more points is better.
			return highscore;
		}

		bool UseSystemMouse() {
			// Return false if the game draws its own cursor or doesn't use
			// the mouse at all.
			return false;
		}

		void Pause() {
			paused = true;
		}

		void Resume() {
			timer = 0;
			paused = false;
		}

		GameSettings* GetSettings() {
			return settings;
		}

		bool RedefinesKeys() {
			return true;
		}

		const char *KeyName(int i) {
			switch (i) {
				case 0: return "Turn Left";
				case 1: return "Turn Right";
				case 2: return "Turn Up";
				case 3: return "Turn Down";
				case 4: return "Start";
				default: return 0;
			};
		}
};


void Centipede::MsgChar(int c) {
	if (!handledLastKey)
		return;

	if (!isPlaying) {
		if (c >= 4) {
			isPlaying = true;
		}
	}

	lastdir = direction;
	if		(c == 0)	direction = MOVE_LEFT;
	else if (c == 1)	direction = MOVE_RIGHT;
	else if (c == 2)	direction = MOVE_UP;
	else if (c == 3)	direction = MOVE_DOWN;
	else return;

	// You can't reverse your direction (you can only turn left or right)
	if (lastdir * direction == MOVE_LEFT * MOVE_RIGHT)	direction = lastdir;
	if (lastdir * direction == MOVE_UP * MOVE_DOWN)		direction = lastdir;

	handledLastKey = false;
}


void Centipede::MoveSnake() {
	// If no direction is defined, we can't move
	if (!direction) return;

	int old_score = score;

	// If the snake is about to crash then wait for a moment or two to give the
	// player one last chance to change the direction
	if (!CanMoveNext() && wait == -1) {
		wait = maxWait;
		score -= (3*speed + growthLevel) * 10;
		if ((score % 10000) > (old_score % 10000)) score = old_score - old_score%10000;
		if (highscore == old_score) highscore = score;
		return;
	}

	if (wait > 0) {
		wait--;
		return;
	}

	wait = -1;

	int i;

	// See if we ate something
	if (HaveFood())	{
		growth += growthLevel;		// make the snake grow some more
		there_is_food = false;		// make a note that there is no food in the playfield
		drop = 10;					// we'll wait this long before dropping the next piece of food

		// increase the total score
		old_score = score;
		float ds = (speed+1)*(speed+2)*(speed+growthLevel);	// the number of points awarded for eating a piece of
		ds = ds * ((600.0f - steps) / 100.0f);		// food depends on speed, growth level the number of step taken
		int episode = level/LEVELS_PER_EPISODE+1;	// and the current episode
		ds *= (float)episode;
		ds /= 10.0f;
		ds = ds >= 1.0f ? ds : 0.0f;
		score += (int)ds;
		steps = 0;

		// go to next level after every xxx pieces of food
		pieces++;
		if (pieces >= maxPieces) {
			pieces = 0;
			score += (speed + growthLevel)*100;
			level++;
			// when all the levels are finnished start at the beginning only this
			// time the player has to eat 10 more pieces per level
			if (level > MAXLEVEL) {
				level = 0;
				maxPieces += 10;
			}
			RestartLevel(level);
			/*
			if (level/LEVELS_PER_EPISODE+1 > episode) {
				--level;
				gameOver = true;
			}
			else {
				RestartLevel(level);
			}
			*/
		}

		// award an extra life every xxx points
		if ((score % 10000) < (old_score % 10000)) {
			lives++;
		}
	}
	else {
		steps++;
	}

	// Clear the last tile of the snake body if we are not growing; increase length if we are
	if (growth > 0) {
		growth--;
		length++;
	}
	else {
		//DrawTile(x() + 9*snake[length-1][0], y() + 9*snake[length-1][1], color[FLOOR][0], color[FLOOR][1], color[FLOOR][2], BLEND, 20);
		matrix[snake[length-1][0]][snake[length-1][1]] = FLOOR;
	}

	// Move each segment of the snake forward (except the first one, we'll do that later)
	for (i=length-1; i>0; i--) {
		snake[i][0] = snake[i-1][0];
		snake[i][1] = snake[i-1][1];
	}

	// Get the direction vector
	int dx, dy;
	GetDxDy(&dx, &dy);


	// Now do the first segment (the head)
	snake[0][0] += dx;
	snake[0][1] += dy;

	// Do the food dropping routine
	if (!there_is_food)	{
		drop--;
		if (!drop) {
			DropFood();
			there_is_food = true;
			//DrawTile(x() + 9*foodx, y() + 9*foody, color[FOOD][0], color[FOOD][1], color[FOOD][2], BLEND, 20);
		}
	}

	// No comment
	if (!CanMove())
		Crashed();

	// Move the head of the snake on a new tile
	matrix[snake[0][0]][snake[0][1]] = SNAKE;
	//DrawTile(x() + 9*snake[0][0], y() + 9*snake[0][1], color[SNAKE][0], color[SNAKE][1], color[SNAKE][2], animation, (10-speed)>>1);

	// We have just handled a keypress
	handledLastKey = true;
}


// See if the move we made was valid (the head of the snake has to be either on the
// floor on a food piece)
bool Centipede::CanMove() {
	if (!isPlaying)
		return true;

	// Wrap around the playfield if necessary
	snake[0][0] += 50;
	snake[0][1] += 50;
	snake[0][0] %= 50;
	snake[0][1] %= 50;

	if (matrix[snake[0][0]][snake[0][1]] != FLOOR && matrix[snake[0][0]][snake[0][1]] != FOOD)
		return false;

	return true;
}


// See if the snake is about to crash if doesn't change direction
bool Centipede::CanMoveNext() {
	if (!isPlaying)
		return true;

	int nextx, nexty;
	nextx = snake[0][0];
	nexty = snake[0][1];

	int dx, dy;
	GetDxDy(&dx, &dy);
	nextx += dx;
	nexty += dy;

	nextx += 50;
	nexty += 50;
	nextx %= 50;
	nexty %= 50;

	if (matrix[nextx][nexty] != FLOOR && matrix[nextx][nexty] != FOOD)
		return false;

	return true;
}


// See if we just ate something (if the head is on top of a food piece)
bool Centipede::HaveFood() {
	if (snake[0][0] == foodx && snake[0][1] == foody) {
		foodx = -1;		// this will remove the food piece from the playfield
		foody = -1;
		return true;
	}
	else
		return false;
}


// Drop a piece of food on a random floor tile
void Centipede::DropFood() {
	// First clear any leftovers
	if (foodx != -1)
		matrix[foodx][foody] = FLOOR;

	srand((unsigned)time(NULL));
	bool found = false;
	// Look for an empty floor tile
	while (!found) {
		foodx = rand() % 50;
		foody = rand() % 50;
		if (matrix[foodx][foody] == FLOOR)
			found = true;
	}

	// Drop the food
	matrix[foodx][foody] = FOOD;
}


// Get the direction vector (how many tiles to move on the x and y axis
// for a particular direction)
void Centipede::GetDxDy(int *dx, int *dy) {
	switch (direction) {
	case MOVE_UP:
		*dx = 0;
		*dy = -1;
		break;
	case MOVE_LEFT:
		*dx = -1;
		*dy = 0;
		break;
	case MOVE_RIGHT:
		*dx = 1;
		*dy = 0;
		break;
	case MOVE_DOWN:
		*dx = 0;
		*dy = 1;
		break;
	default:
		*dx = 0;
		*dy = 0;
		break;
	};
}


// Reset the playfield and the snake before starting a new game
void Centipede::Reset() {
	gameOver = false;	// we're just starting a game
	length = 4;			// initial length
	score = 0;			// initial score
	speed = 4;			// default speed
	lives = 3;			// initial number of lives
	growthLevel = 3;	// default growth level
	level = 0;
	pieces = 0;
	wait = -1;
	maxPieces = 20;
	RestartLevel(level);
}


// Load an arena
void Centipede::LoadArena(int l) {
	char filename[128];
	usprintf(filename, "%scentipede.dat", game_path);
	DATAFILE *levelDat = load_datafile(filename);
	//DATAFILE *levelDat = load_datafile("games/centgames/centipede/centipede.dat");
	if (!levelDat) return;

	char *data = (char *)levelDat[l].dat;

	int tile, i=0;
	for (int y=0; y<50; y++) {
		for (int x=0; x<50; x++) {
			tile = data[i++];
			if (tile != WALL) tile = FLOOR;
			matrix[x][y] = tile;
		}
	}

	startx = data[i++];
	starty = data[i++];

	unload_datafile(levelDat);
}

void Centipede::RestartLevel(int l) {
	direction = MOVE_RIGHT;
	lastdir = 0;
	growth = 0;
	length = 4;
	isPlaying = false;			// we're not playing until the user wants to
	drop = 10;					// we'll wait this long before dropping food
	there_is_food = false;		// there is no food yet
	foodx = -1;
	foody = -1;
	steps = 0;					// we haven't taken any steps yet
	gameOver = false;

	// Initialize the snake array with -1's
	int i;
	for (i=0; i<1000; i++) {
		snake[i][0] = -1;
		snake[i][1] = -1;
	}

	LoadArena(l);

	// Calculate dx and dy (according to direction)
	handledLastKey = true;
	int dx, dy;
	GetDxDy(&dx, &dy);

	// Put a snake into the playfield
	int cx, cy;
	cx = startx;
	cy = starty;
	for (i=0; i<length; i++) {
		matrix[cx][cy] = SNAKE;		// the matrix represents the arena
		snake[i][0] = cx;			// the array represents the snake (0 byte is the x
		snake[i][1] = cy;			// and the 1 byte is the y coordinate)
		cx -= dx;
		cy -= dy;
	}
}

// Do some reseting etc. when the snake has crashed into a wall or something
void Centipede::Crashed() {
	int len = length;
	RestartLevel(level);
	growth = len - 4;		// calculate how much the snake will grow
	length = 4;

	// See if we have any lives left
	lives--;				// we crashed -> we lose a life
	if (lives <= 0) {		// we have no lives left :(
		lives = 0;
		gameOver = true;
		isPlaying = true;
	}
}


void Centipede::Play() {
	speed = 4;
	growthLevel = 5;

	isPlaying = true;
	timer = 0;
	install_int(timer_f, 50);
	//simulate_keypress(KEY_LEFT<<8);
}


void Centipede::MsgTimer() {
	if (gameOver) {
		remove_int(timer_f);
		timer = 0;
		/*
		do_game_over();
		if (highscore > maxScore) {
			maxScore = highscore;
			const char *name = get_highscore_name();

			push_config_state();
			set_config_file("acg.hsc");
			set_config_string("CENTIPEDE", "name", name);
			set_config_int("CENTIPEDE", "score", highscore);
			pop_config_state();
		}
		Reset();
		isPlaying = false;
		*/
	}
	else {
		MoveSnake();
	}
}


void Centipede::DrawScore(BITMAP *canvas) {
	int x = SCREEN_W-4;
	int dy = 12;
	int y = this->y-dy;

	rectfill(canvas, x-80, y+2*dy-3, x, y+2*dy+8, col_edit_back);
	rect(canvas, x-80, y+2*dy-3, x, y+2*dy+8, col_border);
	textout_right_ex(canvas, font, "score", x, y+=dy, col_text, -1);
	textprintf_right_ex(canvas, font, x, y+=dy, col_edit_text, -1, "%d", score);
	y += dy-1;

	/*
	rectfill(canvas, x-80, y+2*dy-3, x, y+2*dy+8, col_edit_back);
	rect(canvas, x-80, y+2*dy-3, x, y+2*dy+8, col_border);
	textout_right_ex(canvas, font, "cur. high", x, y+=dy, col_text, -1);
	textprintf_right_ex(canvas, font, x, y+=dy, col_edit_text, -1, "%d", highscore);
	y += dy-1;
	*/

	rectfill(canvas, x-80, y+2*dy-3, x, y+2*dy+8, col_edit_back);
	rect(canvas, x-80, y+2*dy-3, x, y+2*dy+8, col_border);
	textout_right_ex(canvas, font, "lives", x, y+=dy, col_text, -1);
	textprintf_right_ex(canvas, font, x, y+=dy, col_edit_text, -1, "%d", lives);
	y += dy-1;

	int episode = level/LEVELS_PER_EPISODE;
	rectfill(canvas, x-80, y+2*dy-3, x, y+2*dy+8, col_edit_back);
	rect(canvas, x-80, y+2*dy-3, x, y+2*dy+8, col_border);
	textout_right_ex(canvas, font, "episode", x, y+=dy, col_text, -1);
	textprintf_right_ex(canvas, font, x, y+=dy, col_edit_text, -1, "%d/%d", episode+1, MAXLEVEL/LEVELS_PER_EPISODE+1);
	y += dy-1;

	rectfill(canvas, x-80, y+2*dy-3, x, y+2*dy+8, col_edit_back);
	rect(canvas, x-80, y+2*dy-3, x, y+2*dy+8, col_border);
	textout_right_ex(canvas, font, "level", x, y+=dy, col_text, -1);
	//textprintf_right_ex(canvas, font, x, y+=dy, col_edit_text, -1, "%d/%d", level+1, MAXLEVEL+1);
	textprintf_right_ex(canvas, font, x, y+=dy, col_edit_text, -1, "%d/%d", level%LEVELS_PER_EPISODE+1, (MAXLEVEL+1)/(MAXLEVEL/LEVELS_PER_EPISODE+1));
	y += dy-1;

	rectfill(canvas, x-80, y+2*dy-3, x, y+2*dy+8, col_edit_back);
	rect(canvas, x-80, y+2*dy-3, x, y+2*dy+8, col_border);
	textout_right_ex(canvas, font, "pieces", x, y+=dy, col_text, -1);
	textprintf_right_ex(canvas, font, x, y+=dy, col_edit_text, -1, "%d/%d", pieces, maxPieces);
	y += dy-1;

}


int str_to_col(const char *str) {
	char buf[16];
	ustrcpy(buf, str);
	char *tok1 = ustrtok(buf, ",; ");
	char *tok2 = ustrtok(0, ",; ");
	char *tok3 = ustrtok(0, ",; ");
	int r = (int)uatof(tok1);
	int g = (int)uatof(tok2);
	int b = (int)uatof(tok3);
	return makecol(r,g,b);
}

void Centipede::LoadColors(int index) {
	char options[4096];
	char path[256];

	ustrcpy(options, settings[1].options);
	char *tok = ustrtok(options, "|");
	for (int i=0; i<index; ++i) {
		tok = ustrtok(0, "|");
	}
	usprintf(path, "%s%s.col", game_path, tok);
	//usprintf(path, "games/centipede/%s.col", tok);

	push_config_state();
	set_config_file(path);

	color[WALL][0] = str_to_col(get_config_string("colors", "wall0", "0,0,0"));
	color[WALL][1] = str_to_col(get_config_string("colors", "wall1", "0,0,0"));
	color[WALL][2] = str_to_col(get_config_string("colors", "wall2", "0,0,0"));
	color[FLOOR][0] = str_to_col(get_config_string("colors", "floor0", "0,0,0"));
	color[FLOOR][1] = str_to_col(get_config_string("colors", "floor1", "0,0,0"));
	color[FLOOR][2] = str_to_col(get_config_string("colors", "floor2", "0,0,0"));
	color[SNAKE][0] = str_to_col(get_config_string("colors", "snake0", "0,0,0"));
	color[SNAKE][1] = str_to_col(get_config_string("colors", "snake1", "0,0,0"));
	color[SNAKE][2] = str_to_col(get_config_string("colors", "snake2", "0,0,0"));
	color[FOOD][0] = str_to_col(get_config_string("colors", "food0", "0,0,0"));
	color[FOOD][1] = str_to_col(get_config_string("colors", "food1", "0,0,0"));
	color[FOOD][2] = str_to_col(get_config_string("colors", "food2", "0,0,0"));
	color[BORDER][0] = str_to_col(get_config_string("colors", "border", "0,0,0"));
	col_border = str_to_col(get_config_string("colors", "border", "0,0,0"));
	col_back = str_to_col(get_config_string("colors", "back", "0,0,0"));
	col_edit_back = str_to_col(get_config_string("colors", "edit_back", "0,0,0"));
	col_edit_text = str_to_col(get_config_string("colors", "edit_text", "0,0,0"));
	col_text = str_to_col(get_config_string("colors", "text", "0,0,0"));

	pop_config_state();

	/*
	switch (settings[1].value) {
		case 0:
			color[WALL][0] = makecol(60,120,140);
			color[WALL][1] = makecol(100,160,200);
			color[WALL][2] = makecol(40,80,100);
			color[FLOOR][0] = makecol(240,240,220);
			color[FLOOR][1] = makecol(244,244,224);
			color[FLOOR][2] = makecol(236,236,216);
			color[SNAKE][0] = makecol(240,80,120);
			color[SNAKE][1] = makecol(248,120,140);
			color[SNAKE][2] = makecol(200,60,80);
			color[FOOD][0] = makecol(120,180,60);
			color[FOOD][1] = makecol(140,210,75);
			color[FOOD][2] = makecol(100,150,45);
			color[BORDER][0] = makecol(0,0,0);
			col_edit_back = makecol(192,192,192);
			col_text = makecol(0,0,0);
			col_edit_text = makecol(0,0,0);
			col_border = makecol(0,0,0);
			col_back = makecol(208,208,208);
		break;

		case 1:
			color[WALL][0] = makecol(40,38,36);
			color[WALL][1] = makecol(50,48,46);
			color[WALL][2] = makecol(30,28,26);
			color[FLOOR][0] = makecol(62,60,59);
			color[FLOOR][1] = makecol(66,64,63);
			color[FLOOR][2] = makecol(58,56,55);
			color[SNAKE][0] = makecol(89,87,85);
			color[SNAKE][1] = makecol(118,116,114);
			color[SNAKE][2] = makecol(69,67,65);
			color[FOOD][0] = makecol(0,104,144);
			color[FOOD][1] = makecol(20,144,184);
			color[FOOD][2] = makecol(0,84,124);
			color[BORDER][0] = makecol(0,0,0);
			col_edit_back = makecol(62,60,59);
			col_text = makecol(192,192,192);
			col_edit_text = makecol(0,160,221);
			col_border = makecol(0,0,0);
			col_back = makecol(48,48,48);
		break;
	};
	*/
}


extern "C" DLLEXPORT IGame* GetPlugin() {
	return new Centipede;
}
